/*!
 * Copyright (c) Microsoft Corporation and contributors. All rights reserved.
 * Licensed under the MIT License.
 */
/**
 * @internal
 */
export interface IOdspTokens {
    readonly accessToken: string;
    readonly refreshToken: string;
}
/**
 * Configuration for a public client.
 * @internal
 */
export interface IPublicClientConfig {
    clientId: string;
}
/**
 * @alpha
 */
export interface IOdspAuthRequestInfo {
    accessToken: string;
    refreshTokenFn?: () => Promise<string>;
}
/**
 * @internal
 */
export type TokenRequestCredentials = {
    grant_type: "authorization_code";
    code: string;
    redirect_uri: string;
} | {
    grant_type: "refresh_token";
    refresh_token: string;
} | {
    grant_type: "password";
    username: string;
    password: string;
};
/**
 * @alpha
 */
export declare const getOdspScope: (server: string) => string;
/**
 * @alpha
 */
export declare const pushScope = "offline_access https://pushchannel.1drv.ms/PushChannel.ReadWrite.All";
/**
 * @internal
 */
export declare function getFetchTokenUrl(server: string): string;
/**
 * @internal
 */
export declare function getLoginPageUrl(server: string, clientConfig: IPublicClientConfig, scope: string, odspAuthRedirectUri: string): string;
/**
 * @internal
 */
export declare const getOdspRefreshTokenFn: (server: string, clientConfig: IPublicClientConfig, tokens: IOdspTokens) => () => Promise<string>;
/**
 * @internal
 */
export declare const getPushRefreshTokenFn: (server: string, clientConfig: IPublicClientConfig, tokens: IOdspTokens) => () => Promise<string>;
/**
 * @internal
 */
export declare const getRefreshTokenFn: (scope: string, server: string, clientConfig: IPublicClientConfig, tokens: IOdspTokens) => () => Promise<string>;
/**
 * Fetch an access token and refresh token from AAD
 * @param server - The server to auth against
 * @param scope - The desired oauth scope
 * @param clientConfig - Info about this client's identity
 * @param credentials - Credentials authorizing the client for the requested token
 * @internal
 */
export declare function fetchTokens(server: string, scope: string, clientConfig: IPublicClientConfig, credentials: TokenRequestCredentials): Promise<IOdspTokens>;
/**
 * Fetch fresh tokens.
 * @param server - The server to auth against
 * @param scope - The desired oauth scope
 * @param clientConfig - Info about this client's identity
 * @param tokens - The tokens object provides the refresh token for the request
 *
 * @returns The tokens object with refreshed tokens.
 * @internal
 */
export declare function refreshTokens(server: string, scope: string, clientConfig: IPublicClientConfig, tokens: IOdspTokens): Promise<IOdspTokens>;
/**
 * Issue the requestCallback, providing the proper auth header based on authRequestInfo,
 * and retrying with a refreshed token if necessary.
 * @internal
 */
export declare function authRequestWithRetry(authRequestInfo: IOdspAuthRequestInfo, requestCallback: (config: RequestInit) => Promise<Response>): Promise<Response>;
//# sourceMappingURL=odspAuth.d.ts.map